# -*- coding: utf-8 -*-

from django.shortcuts import render, get_object_or_404, redirect
from django.template.loader import render_to_string
from datetime import datetime
from lib.access_auth import permission_needed
from lib.tools import confirmation

from infos_reseau.forms import InfoReseauForm
from infos_reseau.models import InfoReseau


def widget(request):
    try:
        derniere_info = InfoReseau.objects.filter(fin_aff__gt=datetime.today()).order_by("pub_date")[0]
    except IndexError:
        return None

    c = {
        "derniere_info": derniere_info,
    }

    return (
        render_to_string("infos_reseau/widget.html", c),
        "vert" if derniere_info.est_reprise else "rouge",
    )


@permission_needed("root")
def gestion(request, id=None):
    if id is not None:
        info = get_object_or_404(InfoReseau, id=id)
    else:
        info = None

    if request.method == "POST":
        form = InfoReseauForm(request.POST, instance=info)

        if form.is_valid():
            form.save()

            return redirect("gestion:infos_reseau:gestion")

    else:
        form = InfoReseauForm(instance=info)

    c = {
        "form": form,
        "info": info,
        "infos": InfoReseau.objects.order_by("-pub_date")[0:5],
    }

    return render(request, "infos_reseau/gestion.html", c)


@permission_needed("root")
def supprimer(request, id):
    info = get_object_or_404(InfoReseau, id=id)

    if request.method != "POST":
        message = "Êtes-vous sûr de vouloir supprimer cette info réseau ?"
        boutons = [("conf_annul", "Annuler"), ("conf_ok", "Supprimer l'info réseau")]
        return confirmation(request, message, boutons, "Suppression d’une info réseau")

    if "conf_ok" in request.POST:
        info.delete()

    return redirect("gestion:infos_reseau:gestion")
